==> SAGElyzer_1.3.0.tar.gz: SAGElyzer/R/SAGEMapper.R <==
# Functions that download mapping information from LocusLink, process
# the data, and then map SAGE tags to LocusLink ids.
#
# Copyright 2002, J. Zhang. All rights reserved.
#

SAGEMapper <- function(tag2UG = TRUE, tagUrl =
    "ftp://ftp.ncbi.nih.gov/pub/sage/map/Hs/NlaIII/SAGEmap_tag_ug-rel.zip",
                       organism = "Hs", fromWeb = TRUE){

    # Always save data to the "data" directory
    targetPath <- file.path(.path.package("SAGElyzer"), "temp")
    if(fromWeb){
        # File dowloaded will be named the same as the source file
        tagFName <- file.path(targetPath, gsub("^.*/(.*)", "\\1", tagUrl))
        print("Downloading file")
        download.file(tagUrl, tagFName, method = "internal", quiet = TRUE)
        #unzipFile(tagFName)
        unzipFile(tagFName, where = targetPath,isgz = FALSE)
        tagFName <- getMapFileName()
    }else{
        tagFName <- tagUrl
    }
    print("Finding the mappings")
    if(tag2UG){
        # Maps SAGE tags to UniGene ids
        tagNUG <- doTag2UG(tagFName)
    }else{
        # Maps UniGene ids to SAGE tags
        tagNUG <- doUG2Tag(tagFName)
    }
    mapName <- file.path(targetPath, basename(tempfile("tagmap")))
    # Write to file for later use
    print("Writing data to database table")
    write.table(tagNUG, mapName, sep = "\t", quote = FALSE,
                col.names = FALSE, row.names = FALSE)
    # Write file to a DB table unsing copy which is efficient
    writeSAGE2DB(getSLyzerArgs()[["dbArgs"]], c("tag", "ug"),
                 "", "", fileName = mapName,
                 charNum = c(tag = 21, ug = 150), what = "map")
#    writeTagUGMap(mapName)
    unlink(mapName)
    if(.Platform$OS.type == "unix" && fromWeb){
         curDir <- getwd()
         setwd(targetPath)
         system(paste("chmod +x", organism))
         system(paste("rm -r", organism))
         setwd(curDir)
    }
}

#unzipFile <- function(fileName, where =
#                      file.path(.path.package("SAGElyzer"), "temp")){
#    curDir <- getwd()
#    setwd(where)
#    if(.Platform$OS.type == "unix"){
#        if(!is.null(getOption("unzip"))){
#            system(paste(getOption("unzip"), basename(fileName)))
#        }else{
#            stop("Can not find unzip in the path")
#        }
#    }else if(.Platform$OS.type == "windows"){
#        zip.unpack(fileName, getwd())
#    }else{
#        stop(paste("Do not know how to unzip file under", .Platform$OS.type))
#    }
#    setwd(curDir)
#}

doTag2UG <- function(fileName){
    dataRead <- read.table(fileName, sep = "\t",
                           header = FALSE, quote = "", comment.char =  "")
    dataRead <- cbind(as.vector(dataRead[,1]),
                      paste(dataRead[,2], dataRead[,3], sep = "."))
    return(dataRead)
}

doUG2Tag <- function(fileName, sep = "\t", header = FALSE){
    dataRead <- read.table(fileName, sep = "\t",
                           header = FALSE, quote = "", comment.char =  "")
    dataRead <- cbind(paste(dataRead[,2], dataRead[,3], sep = "."),
                      as.vector(dataRead[,1]))
    return(dataRead)
}

getMapFileName <- function(){
    return(file.path(.path.package("SAGElyzer"), "temp", "Hs",
    "NlaIII", "SAGEmap_tag_ug-rel"))
}

#writeTagUGMap <- function(fileName, dbArgs =
#                          getSLyzerArgs()[["dbArgs"]], what = "map"){

#    conn <- makeConnection(dbArgs)

#    if(tableExists(conn, dbArgs[[what]])){
#        executeQuery(paste("drop table", dbArgs[[what]]), conn, TRUE)
#    }

    # Create an empty table
#    newTableSQL <- paste("create table ", dbArgs[[what]], " ( ",
#                         getColSQL(c("tag", "ug"), 40, "tag", ""),
#                         "primary key(tag))")

#    executeQuery(newTableSQL, conn, TRUE)
    # Copy file to the table created
 #   writeSQL <- paste("copy ", dbArgs[[what]], " from '", fileName,
#                      "' using delimiters '\t'", sep = "")
#    executeQuery(writeSQL, conn, TRUE)

#    closeConn(conn)
#    writeSAGE2DB(dbArgs, c("tag", "ug"), "", "", fileName = fileName,
#                 charNum = c(tag = 21, ug = 150), what = what)
#}

==> SAGElyzer_1.17.0.tar.gz: SAGElyzer/R/SAGEMapper.R <==
# Functions that download mapping information from LocusLink, process
# the data, and then map SAGE tags to LocusLink ids.
#
# Copyright 2002, J. Zhang. All rights reserved.
#

SAGEMapper <- function(tag2UG = TRUE, tagUrl =
    "ftp://ftp.ncbi.nih.gov/pub/sage/map/Hs/NlaIII/SAGEmap_tag_ug-rel.zip",
                       organism = "Hs", fromWeb = TRUE){

    # Always save data to the "data" directory
    targetPath <- file.path(.path.package("SAGElyzer"), "temp")
    if(fromWeb){
        # File dowloaded will be named the same as the source file
        tagFName <- file.path(targetPath, gsub("^.*/(.*)", "\\1", tagUrl))
        print("Downloading file")
        download.file(tagUrl, tagFName, method = "internal", quiet = TRUE)
        #unzipFile(tagFName)
        unzipFile(tagFName, where = targetPath)
        tagFName <- getMapFileName()
    }else{
        tagFName <- tagUrl
    }
    print("Finding the mappings")
    if(tag2UG){
        # Maps SAGE tags to UniGene ids
        tagNUG <- doTag2UG(tagFName)
    }else{
        # Maps UniGene ids to SAGE tags
        tagNUG <- doUG2Tag(tagFName)
    }
    mapName <- file.path(targetPath, basename(tempfile("tagmap")))
    # Write to file for later use
    print("Writing data to database table")
    write.table(tagNUG, mapName, sep = "\t", quote = FALSE,
                col.names = FALSE, row.names = FALSE)
    # Write file to a DB table unsing copy which is efficient
    writeSAGE2DB(getSLyzerArgs()[["dbArgs"]], c("tag", "ug"),
                 "", "", fileName = mapName,
                 charNum = c(tag = 21, ug = 150), what = "map")
#    writeTagUGMap(mapName)
    unlink(mapName)
    if(.Platform$OS.type == "unix" && fromWeb){
         curDir <- getwd()
         setwd(targetPath)
         system(paste("chmod +x", organism))
         system(paste("rm -r", organism))
         setwd(curDir)
    }
}

unzipFile <- function(fileName, where =
                      file.path(.path.package("SAGElyzer"), "temp")){
    curDir <- getwd()
    setwd(where)
    if(.Platform$OS.type == "unix"){
        if(!is.null(getOption("unzip"))){
            system(paste(getOption("unzip"), basename(fileName)))
        }else{
            stop("Can not find unzip in the path")
        }
    }else if(.Platform$OS.type == "windows"){
        zip.unpack(fileName, getwd())
    }else{
        stop(paste("Do not know how to unzip file under", .Platform$OS.type))
    }
    setwd(curDir)
}

doTag2UG <- function(fileName){
    dataRead <- read.table(fileName, sep = "\t",
                           header = FALSE, quote = "", comment.char =  "")
    dataRead <- cbind(as.vector(dataRead[,1]),
                      paste(dataRead[,2], dataRead[,3], sep = "."))
    return(dataRead)
}

doUG2Tag <- function(fileName, sep = "\t", header = FALSE){
    dataRead <- read.table(fileName, sep = "\t",
                           header = FALSE, quote = "", comment.char =  "")
    dataRead <- cbind(paste(dataRead[,2], dataRead[,3], sep = "."),
                      as.vector(dataRead[,1]))
    return(dataRead)
}

getMapFileName <- function(){
    return(file.path(.path.package("SAGElyzer"), "temp", "Hs",
    "NlaIII", "SAGEmap_tag_ug-rel"))
}

#writeTagUGMap <- function(fileName, dbArgs =
#                          getSLyzerArgs()[["dbArgs"]], what = "map"){

#    conn <- makeConnection(dbArgs)

#    if(tableExists(conn, dbArgs[[what]])){
#        executeQuery(paste("drop table", dbArgs[[what]]), conn, TRUE)
#    }

    # Create an empty table
#    newTableSQL <- paste("create table ", dbArgs[[what]], " ( ",
#                         getColSQL(c("tag", "ug"), 40, "tag", ""),
#                         "primary key(tag))")

#    executeQuery(newTableSQL, conn, TRUE)
    # Copy file to the table created
 #   writeSQL <- paste("copy ", dbArgs[[what]], " from '", fileName,
#                      "' using delimiters '\t'", sep = "")
#    executeQuery(writeSQL, conn, TRUE)

#    closeConn(conn)
#    writeSAGE2DB(dbArgs, c("tag", "ug"), "", "", fileName = fileName,
#                 charNum = c(tag = 21, ug = 150), what = what)
#}
